drop database if exists `test`;
create database `test`;
use `test`;


drop table if exists `users`;
create table `users`(
`username` varchar(50) primary key,
`firstname` varchar(50),
`lastname` varchar(50),
`password` varchar(50),
`userType` enum ('User', 'Manager', 'Admin', 'Customer', 'CustomerManager', 'CustomerAdmin'),
`status` enum ('Approved', 'Pending', 'Declined')
);


drop table if exists `company`;
create table `company`(
`comName` varchar(50) primary key
);


drop table if exists `customerCreditCard`;
create table customerCreditCard(
`creditCardNum` decimal(16,0) primary key,
`username` varchar(50),
Constraint `fk2` foreign key (`username`) References `users` (`username`)
);


drop table if exists `employee`;
create table `employee`(
`username` varchar(50) primary key,
`manStreet`	varchar(50),
`manCity` varchar(50),
`manState` enum(
'AL','AK','AZ','AR','CA','CO','CT','DE','DC','FL','GA','HI','ID','IL','IN','IA','KS','KY','LA','ME','MD','MA','MI','MN','MS','MO','MT','NE','NV','NH','NJ','NM','NY','NC','ND','OH','OK','OR','PA','RI','SC','SD','TN','TX','UT','VT','VA','WA','WV','WI','WY'
),
`manZipcode` decimal(5,0),
`employeeType` enum('Admin','Manager'),
`comName` varchar(50),
`thName` varchar(50),
Constraint `fk3` foreign key (`username`) references `users` (`username`),
Constraint `fk6` foreign key (`comName`) references `company` (`comName`),
Constraint `UniqueAddress` UNIQUE (`manZipcode`,`manStreet`,`manCity`,`manState`)
);


drop table if exists `theater`;
create table `theater`(
`thName` varchar(50),
`comName` varchar(50),
`username` varchar(50),
`thZipcode` decimal(5,0),
`thStreet` varchar(50),
`thCity` varchar(50),
`thState` enum(
'AL','AK','AZ','AR','CA','CO','CT','DE','DC','FL','GA','HI','ID','IL','IN','IA','KS','KY','LA','ME','MD','MA','MI','MN','MS','MO','MT','NE','NV','NH','NJ','NM','NY','NC','ND','OH','OK','OR','PA','RI','SC','SD','TN','TX','UT','VT','VA','WA','WV','WI','WY'
),
`Capacity` int,
primary key (`comName`, `thName`),
Constraint `fk7` foreign key (`comName`) references `company` (`comName`),
Constraint `fk8` foreign key (`username`) references `employee` (`username`)
);


drop table if exists `movie`;
create table movie(
`movName` varchar(50),
`movReleaseDate` Date,
`Duration` int,
primary key (`movName`, `movReleaseDate`)
);


drop table if exists `movieplay`;
create table movieplay(
`movPlayDate` Date,
`movName` varchar(50),
`movReleaseDate` Date,
`thName` varchar(50),
`comName` varchar(50),
primary key (`movPlayDate`,`movName`,`movReleaseDate`,`thName`,`comName`),
Constraint `fk9` foreign key (`comName`,`thName`) references `theater` (`comName`,`thName`),
Constraint `fk10` foreign key (`movName`,`movReleaseDate`) references `movie` (`movName`, `movReleaseDate`)
);


drop table if exists `customerviewmovie`;
create table customerviewmovie(
`movName` varchar(50),
`movReleaseDate` Date,
`movPlayDate` Date,
`thName` varchar(50),
`comName` varchar(50),
`CreditCardNum` decimal (16,0),
Constraint fk11 foreign key (`creditCardNum`) references `customercreditcard` (`CreditCardNum`),
Constraint fk12 foreign key (`movPlayDate`,`movName`,`movReleaseDate`,`thName`,`comName`) references `movieplay` (`movPlayDate`,`movName`,`movReleaseDate`,`thName`,`comName`)
);


drop table if exists `UserVisitTheater`;
create table UserVisitTheater(
`Username` varchar(50),
`thName` varchar(50),
`comName` varchar(50),
`visitDate` Date,
`VisitID` int primary key AUTO_INCREMENT,
Constraint `fk13` foreign key (`Username`) references `users` (`Username`),
Constraint `fk14` foreign key (`comName`,`thName`) references `theater` (`comName`,`thName`)
);

Drop view if exists userloginview;
create view userloginview as 
select users.username as un, userType, 
case when userType = 'Manager' THEN 0
   when userType = 'User' THEN 0
   when userType = 'Admin' THEN 0
   ELSE 1
   END AS isCustomer,
case when employeeType = 'Manager' THEN 1
	 when employeeType = 'CustomerManager' THEN 1
ELSE 0
END AS isManager,
case when employeeType = 'Admin' THEN 1
	 when employeeType = 'CustomerAdmin' THEN 1
ELSE 0
END AS isAdmin
   from users
   left join employee on users.username = employee.username;
   
   
Insert into users (username , firstname , lastname , password , userType , status) values ( 'georgep' , 'George P.' , 'Burdell' , MD5(111111111) , 'CustomerManager' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'calcwizard' , 'Issac' , 'Newton' , MD5(222222222) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'calcultron' , 'Dwight' , 'Schrute' , MD5(333333333) , 'CustomerManager' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'calcultron2' , 'Jim' , 'Halpert' , MD5(444444444) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'gdanger' , 'Gary' , 'Danger' , MD5(555555555) , 'User' , 'Declined');Insert into users (username , firstname , lastname , password , userType , status) values ( 'imbatman' , 'Bruce' , 'Wayne' , MD5(666666666) , 'Manager' , 'Approved');
Insert into users (username , firstname , lastname , password , userType , status) values ( 'imready' , 'Spongebob' , 'Squarepants' , MD5(777777777) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'isthisthekrustykrab' , 'Patrick' , 'Star' , MD5(888888888) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'clarinetbeast' , 'Squidward' , 'Tentacles' , MD5(999999999) , 'Customer' , 'Declined');Insert into users (username , firstname , lastname , password , userType , status) values ( 'texasStarKarate' , 'Sandy' , 'Cheeks' , MD5(111111110) , 'User' , 'Declined');Insert into users (username , firstname , lastname , password , userType , status) values ( 'fullMetal' , 'Edward' , 'Elric' , MD5(111111100) , 'Customer' , 'Approved');
Insert into users (username , firstname , lastname , password , userType , status) values ( 'notFullMetal' , 'Alphonse' , 'Elric' , MD5(111111100) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'ilikemoney$$' , 'Eugene' , 'Krabs' , MD5(111111110) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'eeqmcsquare' , 'Albert' , 'Einstein' , MD5(111111110) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'theScienceGuy' , 'Bill' , 'Nye' , MD5(999999999) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'entropyRox' , 'Claude' , 'Shannon' , MD5(999999999) , 'CustomerManager' , 'Approved');
Insert into users (username , firstname , lastname , password , userType , status) values ( 'fatherAI' , 'Alan' , 'Turing' , MD5(222222222) , 'Manager' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'cool_class4400' , 'A. TA' , 'Washere' , MD5(333333333) , 'CustomerAdmin' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'thePiGuy3.14' , 'Archimedes' , 'Syracuse' , MD5(1111111111) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'does2Much' , 'Carl' , 'Gauss' , MD5(1212121212) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'programerAAL' , 'Ada' , 'Lovelace' , MD5(3131313131) , 'Customer' , 'Approved');
Insert into users (username , firstname , lastname , password , userType , status) values ( 'radioactivePoRa' , 'Marie' , 'Curie' , MD5(1313131313) , 'Manager' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'DNAhelix' , 'Rosalind' , 'Franklin' , MD5(777777777) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'ghcghc' , 'Grace' , 'Hopper' , MD5(666666666) , 'Manager' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'RitzLover28' , 'Abby' , 'Normal' , MD5(444444444) , 'Customer' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'smith_j' , 'John' , 'Smith' , MD5(333333333) , 'User' , 'Pending');Insert into users (username , firstname , lastname , password , userType , status) values ( 'manager1' , 'Manager' , 'One' , MD5(1122112211) , 'Manager' , 'Approved');
Insert into users (username , firstname , lastname , password , userType , status) values ( 'manager2' , 'Manager' , 'Two' , MD5(3131313131) , 'Manager' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'manager3' , 'Three' , 'Three' , MD5(8787878787) , 'Manager' , 'Approved');Insert into users (username , firstname , lastname , password , userType , status) values ( 'manager4' , 'Four' , 'Four' , MD5(5755555555) , 'Manager' , 'Approved');

   
Insert into Company (comName) values ( 'EZ Theater Company');Insert into Company (comName) values ( '4400 Theater Company');Insert into Company (comName) values ( 'Awesome Theater Company');Insert into Company (comName) values ( 'AI Theater Company');Insert into Company (comName) values ( '');


Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'cool_class4400' , '' , '' , null , null , 'Admin' , '' , '');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'entropyRox' , '200 Cool Place' , 'San Francisco ' , 'CA' , 94016 , 'Manager' , '4400 Theater Company' , 'Cinema Star');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'fatherAI' , '456 Main St' , 'New York' , 'NY' , 10001 , 'Manager' , 'EZ Theater Company' , 'Main Movies');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'georgep' , '10 Pearl Dr' , 'Seattle' , 'WA' , 98105 , 'Manager' , '4400 Theater Company' , 'Jonathan''s Movies');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'calcultron' , '123 Peachtree St' , 'Atlanta' , 'GA' , 30308 , 'Manager' , 'EZ Theater Company' , 'Star Movies');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'imbatman' , '800 Color Dr' , 'Austin' , 'TX' , 78653 , 'Manager' , 'Awesome Theater Company' , 'ABC Theater');
Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'ghcghc' , '100 Pi St' , 'Pallet Town' , 'KS' , 31415 , 'Manager' , 'AI Theater Company' , 'ML Movies');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'radioactivePoRa' , '100 Blu St' , 'Sunnyvale' , 'CA' , 94088 , 'Manager' , '4400 Theater Company' , 'Star Movies');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'manager1' , '123 Ferst Drive' , 'Atlanta' , 'GA' , 30332 , 'Manager' , '4400 Theater Company' , '');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'manager2' , '456 Ferst Drive' , 'Atlanta' , 'GA' , 30332 , 'Manager' , 'AI Theater Company' , '');Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'manager3' , '789 Ferst Drive' , 'Atlanta' , 'GA' , 30332 , 'Manager' , '4400 Theater Company' , '');
Insert into employee (username , manStreet , manCity , manState , manZipcode , employeeType , comName , thName)  values ( 'manager4' , '000 Ferst Drive' , 'Atlanta' , 'GA' , 30332 , 'Manager' , '4400 Theater Company' , '');

Insert into CustomerCreditCard (username , creditCardNum) values ( 'georgep' , 1111111111111111);Insert into CustomerCreditCard (username , creditCardNum) values ( 'georgep' , 1111111111111110);Insert into CustomerCreditCard (username , creditCardNum) values ( 'georgep' , 1111111111111100);Insert into CustomerCreditCard (username , creditCardNum) values ( 'georgep' , 1111111111111000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'georgep' , 1111111111110000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'calcwizard' , 1111111111100000);
Insert into CustomerCreditCard (username , creditCardNum) values ( 'calcultron' , 1111111111000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'calcultron2' , 1111111110000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'calcultron2' , 1111111100000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'imready' , 1111110000000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'isthisthekrustykrab' , 1111100000000000);
Insert into CustomerCreditCard (username , creditCardNum) values ( 'isthisthekrustykrab' , 1111000000000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'isthisthekrustykrab' , 1110000000000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'fullMetal' , 1100000000000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'notFullMetal' , 1000000000000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'ilikemoney$$' , 9000000000000000);
Insert into CustomerCreditCard (username , creditCardNum) values ( 'ilikemoney$$' , 2222222222222222);Insert into CustomerCreditCard (username , creditCardNum) values ( 'ilikemoney$$' , 2222222222222220);Insert into CustomerCreditCard (username , creditCardNum) values ( 'eeqmcsquare' , 2222222222222200);Insert into CustomerCreditCard (username , creditCardNum) values ( 'theScienceGuy' , 2222222222222000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'entropyRox' , 2222222222220000);
Insert into CustomerCreditCard (username , creditCardNum) values ( 'entropyRox' , 2222222222200000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'cool_class4400' , 2222222222000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'thePiGuy3.14' , 2222222220000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'does2Much' , 2222222200000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'programerAAL' , 2222222000000000);Insert into CustomerCreditCard (username , creditCardNum) values ( 'DNAhelix' , 2220000000000000);
Insert into CustomerCreditCard (username , creditCardNum) values ( 'RitzLover28' , 3333333333333300);

Insert into theater (comName , thName , capacity , thStreet , thCity , thState , thZipcode) values ( 'EZ Theater Company' , 'Main Movies' , 3 , '123 Main St' , 'New York' , 'NY' , 10001);Insert into theater (comName , thName , capacity , thStreet , thCity , thState , thZipcode) values ( 'EZ Theater Company' , 'Star Movies' , 2 , '745 GT St' , 'Atlanta' , 'GA' , 30332);Insert into theater (comName , thName , capacity , thStreet , thCity , thState , thZipcode) values ( '4400 Theater Company' , 'Cinema Star' , 4 , '100 Cool Place' , 'San Francisco ' , 'CA' , 94016);Insert into theater (comName , thName , capacity , thStreet , thCity , thState , thZipcode) values ( '4400 Theater Company' , 'Star Movies' , 5 , '4400 Rocks Ave' , 'Boulder' , 'CA' , 80301);Insert into theater (comName , thName , capacity , thStreet , thCity , thState , thZipcode) values ( '4400 Theater Company' , 'Jonathan''s Movies' , 2 , '67 Pearl Dr' , 'Seattle' , 'WA' , 98101);Insert into theater (comName , thName , capacity , thStreet , thCity , thState , thZipcode) values ( 'Awesome Theater Company' , 'ABC Theater' , 5 , '880 Color Dr' , 'Austin' , 'TX' , 73301);Insert into theater (comName , thName , capacity , thStreet , thCity , thState , thZipcode) values ( 'AI Theater Company' , 'ML Movies' , 3 , '314 Pi St' , 'Pallet Town' , 'KS' , 31415);


Insert into Movie (movName , movReleaseDate , duration) values ( 'How to Train Your Dragon' , '2010-03-21' , 98);Insert into Movie (movName , movReleaseDate , duration) values ( '4400 The Movie' , '2019-08-12' , 130);Insert into Movie (movName , movReleaseDate , duration) values ( 'The First Pokemon Movie' , '1998-07-19' , 75);Insert into Movie (movName , movReleaseDate , duration) values ( 'The King''s Speech' , '2010-11-26' , 119);Insert into Movie (movName , movReleaseDate , duration) values ( 'Avengers: Endgame' , '2019-04-26' , 181);Insert into Movie (movName , movReleaseDate , duration) values ( 'Spaceballs' , '1987-06-24' , 96);Insert into Movie (movName , movReleaseDate , duration) values ( 'Spider-Man: Into the Spider-Verse' , '2018-12-01' , 117);Insert into Movie (movName , movReleaseDate , duration) values ( 'Georgia Tech The Movie' , '1985-08-13' , 100);
Insert into Movie (movName , movReleaseDate , duration) values ( 'George P Burdell''s Life Story' , '1927-08-12' , 100);Insert into Movie (movName , movReleaseDate , duration) values ( 'Calculus Returns: A ML Story' , '2019-09-19' , 314);


Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( '4400 The Movie' , '2019-08-12' , '2019-10-12' , 'ABC Theater' , 'Awesome Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'The First Pokemon Movie' , '1998-07-19' , '2018-07-19' , 'ABC Theater' , 'Awesome Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Georgia Tech The Movie' , '1985-08-13' , '1985-08-13' , 'ABC Theater' , 'Awesome Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-04-02' , 'Cinema Star' , '4400 Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( '4400 The Movie' , '2019-08-12' , '2019-09-12' , 'Cinema Star' , '4400 Theater Company');
Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'The King''s Speech' , '2010-11-26' , '2019-12-20' , 'Cinema Star' , '4400 Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Spaceballs' , '1987-06-24' , '2000-02-02' , 'Cinema Star' , '4400 Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Georgia Tech The Movie' , '1985-08-13' , '2019-09-30' , 'Cinema Star' , '4400 Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'George P Burdell''s Life Story' , '1927-08-12' , '2010-05-20' , 'Cinema Star' , '4400 Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-03-22' , 'Main Movies' , 'EZ Theater Company');
Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-03-23' , 'Main Movies' , 'EZ Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Spaceballs' , '1987-06-24' , '1999-06-24' , 'Main Movies' , 'EZ Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'George P Burdell''s Life Story' , '1927-08-12' , '2019-10-22' , 'Main Movies' , 'EZ Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'George P Burdell''s Life Story' , '1927-08-12' , '2019-07-14' , 'Main Movies' , 'EZ Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'The King''s Speech' , '2010-11-26' , '2019-12-20' , 'Main Movies' , 'EZ Theater Company');
Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Spaceballs' , '1987-06-24' , '2010-04-02' , 'ML Movies' , 'AI Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Spaceballs' , '1987-06-24' , '2023-01-23' , 'ML Movies' , 'AI Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Calculus Returns: A ML Story' , '2019-09-19' , '2019-10-10' , 'ML Movies' , 'AI Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Calculus Returns: A ML Story' , '2019-09-19' , '2019-12-30' , 'ML Movies' , 'AI Theater Company');
Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'Spider-Man: Into the Spider-Verse' , '2018-12-01' , '2019-09-30' , 'ML Movies' , 'AI Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-03-25' , 'Star Movies' , 'EZ Theater Company');Insert into MoviePlay (movName , movReleaseDate , movPlayDate , thName , comName) values ( '4400 The Movie' , '2019-08-12' , '2019-08-12' , 'Star Movies' , 'EZ Theater Company');


Insert into UserVisitTheater (username , thName , comName , visitDate , VisitID) values ( 'georgep' , 'Main Movies' , 'EZ Theater Company' , '2010-03-22' , 1);Insert into UserVisitTheater (username , thName , comName , visitDate , VisitID) values ( 'calcwizard' , 'Main Movies' , 'EZ Theater Company' , '2010-03-22' , 2);Insert into UserVisitTheater (username , thName , comName , visitDate , VisitID) values ( 'calcwizard' , 'Star Movies' , 'EZ Theater Company' , '2010-03-25' , 3);Insert into UserVisitTheater (username , thName , comName , visitDate , VisitID) values ( 'imready' , 'Star Movies' , 'EZ Theater Company' , '2010-03-25' , 4);Insert into UserVisitTheater (username , thName , comName , visitDate , VisitID) values ( 'calcwizard' , 'ML Movies' , 'AI Theater Company' , '2010-03-20' , 5);


Insert into CustomerViewMovie (movName , movReleaseDate , movPlayDate , thName , comName , creditCardNum) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-04-02' , 'Cinema Star' , '4400 Theater Company' , 1111111111111111);Insert into CustomerViewMovie (movName , movReleaseDate , movPlayDate , thName , comName , creditCardNum) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-03-22' , 'Main Movies' , 'EZ Theater Company' , 1111111111111111);Insert into CustomerViewMovie (movName , movReleaseDate , movPlayDate , thName , comName , creditCardNum) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-03-23' , 'Main Movies' , 'EZ Theater Company' , 1111111111111111);Insert into CustomerViewMovie (movName , movReleaseDate , movPlayDate , thName , comName , creditCardNum) values ( 'How to Train Your Dragon' , '2010-03-21' , '2010-03-25' , 'Star Movies' , 'EZ Theater Company' , 1111111111111100);
